pub struct WithColormapImageMix<'a, 'b, 'c, 'd, U, V, T, const N: usize>where
T: PixelColor + Default + Invert + Screen + WeightedAvg,
U: ImageDrawable + Colors<U::Color>,
V: ImageDrawable + Colors<V::Color>,{ /* private fields */ }Expand description
Image with references to two overlapping image drawables and a set of two colormaps.
While also performing color conversion, drawing this image drawable involves mixing the colors
that form pairs of pixels in WeightedAvg blend mode.